# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GroupMemberRequest(Model):
    """GroupMemberRequest.

    :param include_in_charts: The flag determining whether the member is
     included in group charts <span class='property-internal'>Required</span>
    :type include_in_charts: bool
    """

    _validation = {
        'include_in_charts': {'required': True},
    }

    _attribute_map = {
        'include_in_charts': {'key': 'includeInCharts', 'type': 'bool'},
    }

    def __init__(self, include_in_charts):
        super(GroupMemberRequest, self).__init__()
        self.include_in_charts = include_in_charts



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DataTypeResponse(Model):
    """DataTypeResponse.

    :param data_type_id:  <span class='property-internal'>Required
     (defined)</span>
    :type data_type_id: int
    :param data_type_code:  <span class='property-internal'>Required
     (defined)</span>
    :type data_type_code: str
    :param data_type_info:  <span class='property-internal'>Required
     (defined)</span>
    :type data_type_info: str
    """

    _attribute_map = {
        'data_type_id': {'key': 'dataTypeId', 'type': 'int'},
        'data_type_code': {'key': 'dataTypeCode', 'type': 'str'},
        'data_type_info': {'key': 'dataTypeInfo', 'type': 'str'},
    }

    def __init__(self, data_type_id=None, data_type_code=None, data_type_info=None):
        super(DataTypeResponse, self).__init__()
        self.data_type_id = data_type_id
        self.data_type_code = data_type_code
        self.data_type_info = data_type_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UDFFieldChild(Model):
    """UDFFieldChild.

    :param udf_id:  <span class='property-internal'>Required (defined)</span>
    :type udf_id: int
    :param data_type:
    :type data_type: ~energycap.sdk.models.DataTypeResponse
    :param name:  <span class='property-internal'>Required (defined)</span>
    :type name: str
    :param display_order:  <span class='property-internal'>Required
     (defined)</span>
    :type display_order: int
    :param value:  <span class='property-internal'>Required (defined)</span>
    :type value: str
    :param udf_select_values:  <span class='property-internal'>Required
     (defined)</span>
    :type udf_select_values:
     list[~energycap.sdk.models.UDFSelectValueEntityResponse]
    """

    _attribute_map = {
        'udf_id': {'key': 'udfId', 'type': 'int'},
        'data_type': {'key': 'dataType', 'type': 'DataTypeResponse'},
        'name': {'key': 'name', 'type': 'str'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
        'value': {'key': 'value', 'type': 'str'},
        'udf_select_values': {'key': 'udfSelectValues', 'type': '[UDFSelectValueEntityResponse]'},
    }

    def __init__(self, udf_id=None, data_type=None, name=None, display_order=None, value=None, udf_select_values=None):
        super(UDFFieldChild, self).__init__()
        self.udf_id = udf_id
        self.data_type = data_type
        self.name = name
        self.display_order = display_order
        self.value = value
        self.udf_select_values = udf_select_values



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UnitChild(Model):
    """UnitChild.

    :param unit_id: The unit identifier
    :type unit_id: int
    :param unit_code: The unit code
    :type unit_code: str
    :param unit_info: The unit info
    :type unit_info: str
    """

    _attribute_map = {
        'unit_id': {'key': 'unitId', 'type': 'int'},
        'unit_code': {'key': 'unitCode', 'type': 'str'},
        'unit_info': {'key': 'unitInfo', 'type': 'str'},
    }

    def __init__(self, unit_id=None, unit_code=None, unit_info=None):
        super(UnitChild, self).__init__()
        self.unit_id = unit_id
        self.unit_code = unit_code
        self.unit_info = unit_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterCost(Model):
    """MeterCost.

    :param meter:
    :type meter: ~energycap.sdk.models.MeterChild
    :param place:
    :type place: ~energycap.sdk.models.PlaceChild
    :param total_cost: Total cost
    :type total_cost: float
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'meter': {'key': 'meter', 'type': 'MeterChild'},
        'place': {'key': 'place', 'type': 'PlaceChild'},
        'total_cost': {'key': 'totalCost', 'type': 'float'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
    }

    def __init__(self, meter=None, place=None, total_cost=None, cost_unit=None):
        super(MeterCost, self).__init__()
        self.meter = meter
        self.place = place
        self.total_cost = total_cost
        self.cost_unit = cost_unit



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestNormalizedYearlyResponseTargetComparison(Model):
    """PlaceDigestNormalizedYearlyResponseTargetComparison.

    :param target_year: Target year
    :type target_year: int
    :param target_label: Target label
    :type target_label: str
    :param global_use: Total use for the target year
    :type global_use: float
    :param global_use_ytd: Total use for the target year up to the target
     period that corresponds to the current period
    :type global_use_ytd: float
    """

    _attribute_map = {
        'target_year': {'key': 'targetYear', 'type': 'int'},
        'target_label': {'key': 'targetLabel', 'type': 'str'},
        'global_use': {'key': 'globalUse', 'type': 'float'},
        'global_use_ytd': {'key': 'globalUseYtd', 'type': 'float'},
    }

    def __init__(self, target_year=None, target_label=None, global_use=None, global_use_ytd=None):
        super(PlaceDigestNormalizedYearlyResponseTargetComparison, self).__init__()
        self.target_year = target_year
        self.target_label = target_label
        self.global_use = global_use
        self.global_use_ytd = global_use_ytd



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ApiKeyEditRequest(Model):
    """ApiKeyEditRequest.

    :param api_key_name: The name of the API key <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 60 characters</span>
    :type api_key_name: str
    :param api_key_description: A description for the API key <span
     class='property-internal'>Required</span>
    :type api_key_description: str
    """

    _validation = {
        'api_key_name': {'required': True, 'max_length': 60, 'min_length': 0},
        'api_key_description': {'required': True},
    }

    _attribute_map = {
        'api_key_name': {'key': 'apiKeyName', 'type': 'str'},
        'api_key_description': {'key': 'apiKeyDescription', 'type': 'str'},
    }

    def __init__(self, api_key_name, api_key_description):
        super(ApiKeyEditRequest, self).__init__()
        self.api_key_name = api_key_name
        self.api_key_description = api_key_description



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SearchParentPlaceChild(Model):
    """SearchParentPlaceChild.

    :param place_id: The place identifier
    :type place_id: int
    :param place_code: The place code
    :type place_code: str
    :param place_info: The place info
    :type place_info: str
    :param place_type:
    :type place_type: ~energycap.sdk.models.PlaceTypeResponse
    """

    _attribute_map = {
        'place_id': {'key': 'placeId', 'type': 'int'},
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'place_type': {'key': 'placeType', 'type': 'PlaceTypeResponse'},
    }

    def __init__(self, place_id=None, place_code=None, place_info=None, place_type=None):
        super(SearchParentPlaceChild, self).__init__()
        self.place_id = place_id
        self.place_code = place_code
        self.place_info = place_info
        self.place_type = place_type



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillSplitParentDetailsResponse(Model):
    """BillSplitParentDetailsResponse.

    :param split_parent_account:
    :type split_parent_account: ~energycap.sdk.models.AccountChild
    :param split_parent_meter:
    :type split_parent_meter: ~energycap.sdk.models.MeterChild
    :param begin_period: First billing period that the bill split was active
     for
    :type begin_period: int
    :param end_period: Last billing period that the bill split was active for
    :type end_period: int
    """

    _attribute_map = {
        'split_parent_account': {'key': 'splitParentAccount', 'type': 'AccountChild'},
        'split_parent_meter': {'key': 'splitParentMeter', 'type': 'MeterChild'},
        'begin_period': {'key': 'beginPeriod', 'type': 'int'},
        'end_period': {'key': 'endPeriod', 'type': 'int'},
    }

    def __init__(self, split_parent_account=None, split_parent_meter=None, begin_period=None, end_period=None):
        super(BillSplitParentDetailsResponse, self).__init__()
        self.split_parent_account = split_parent_account
        self.split_parent_meter = split_parent_meter
        self.begin_period = begin_period
        self.end_period = end_period



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HierarchicalPlaces2(Model):
    """HierarchicalPlaces2.

    :param parent_id:
    :type parent_id: int
    :param place_id:
    :type place_id: int
    :param place_info:
    :type place_info: str
    :param place_code:
    :type place_code: str
    :param place_type_id:
    :type place_type_id: int
    :param has_children:
    :type has_children: bool
    :param has_place_children:
    :type has_place_children: bool
    :param has_meter_children:
    :type has_meter_children: bool
    :param has_active_children:
    :type has_active_children: bool
    :param has_active_meter_children:
    :type has_active_meter_children: bool
    :param meter_children:
    :type meter_children: list[~energycap.sdk.models.MeterChild]
    :param place_children:
    :type place_children: list[~energycap.sdk.models.HierarchicalPlaces]
    """

    _attribute_map = {
        'parent_id': {'key': 'parentId', 'type': 'int'},
        'place_id': {'key': 'placeId', 'type': 'int'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_type_id': {'key': 'placeTypeId', 'type': 'int'},
        'has_children': {'key': 'hasChildren', 'type': 'bool'},
        'has_place_children': {'key': 'hasPlaceChildren', 'type': 'bool'},
        'has_meter_children': {'key': 'hasMeterChildren', 'type': 'bool'},
        'has_active_children': {'key': 'hasActiveChildren', 'type': 'bool'},
        'has_active_meter_children': {'key': 'hasActiveMeterChildren', 'type': 'bool'},
        'meter_children': {'key': 'meterChildren', 'type': '[MeterChild]'},
        'place_children': {'key': 'placeChildren', 'type': '[HierarchicalPlaces]'},
    }

    def __init__(self, parent_id=None, place_id=None, place_info=None, place_code=None, place_type_id=None, has_children=None, has_place_children=None, has_meter_children=None, has_active_children=None, has_active_meter_children=None, meter_children=None, place_children=None):
        super(HierarchicalPlaces2, self).__init__()
        self.parent_id = parent_id
        self.place_id = place_id
        self.place_info = place_info
        self.place_code = place_code
        self.place_type_id = place_type_id
        self.has_children = has_children
        self.has_place_children = has_place_children
        self.has_meter_children = has_meter_children
        self.has_active_children = has_active_children
        self.has_active_meter_children = has_active_meter_children
        self.meter_children = meter_children
        self.place_children = place_children



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class LicenseResponse(Model):
    """LicenseResponse.

    :param validation_key: User's license validation key.
    :type validation_key: str
    :param expiration_date: User's license expiration date.
    :type expiration_date: datetime
    :param licensed_meters: Number of licensed meters for this user.
    :type licensed_meters: int
    :param user_number: The user number.
    :type user_number: str
    :param version: EnergyCAP version on this license.
    :type version: str
    :param notes: Additional notes related to the license.
    :type notes: str
    :param meter_usage:
    :type meter_usage: ~energycap.sdk.models.AccountOrMeterUsage
    :param account_usage:
    :type account_usage: ~energycap.sdk.models.AccountOrMeterUsage
    :param bills_created_last30_days:
    :type bills_created_last30_days: ~energycap.sdk.models.BillUsage
    :param bills_created_last12_months:
    :type bills_created_last12_months: ~energycap.sdk.models.BillUsage
    :param license_features:
    :type license_features: ~energycap.sdk.models.LicenseFeatures
    """

    _attribute_map = {
        'validation_key': {'key': 'validationKey', 'type': 'str'},
        'expiration_date': {'key': 'expirationDate', 'type': 'iso-8601'},
        'licensed_meters': {'key': 'licensedMeters', 'type': 'int'},
        'user_number': {'key': 'userNumber', 'type': 'str'},
        'version': {'key': 'version', 'type': 'str'},
        'notes': {'key': 'notes', 'type': 'str'},
        'meter_usage': {'key': 'meterUsage', 'type': 'AccountOrMeterUsage'},
        'account_usage': {'key': 'accountUsage', 'type': 'AccountOrMeterUsage'},
        'bills_created_last30_days': {'key': 'billsCreatedLast30Days', 'type': 'BillUsage'},
        'bills_created_last12_months': {'key': 'billsCreatedLast12Months', 'type': 'BillUsage'},
        'license_features': {'key': 'licenseFeatures', 'type': 'LicenseFeatures'},
    }

    def __init__(self, validation_key=None, expiration_date=None, licensed_meters=None, user_number=None, version=None, notes=None, meter_usage=None, account_usage=None, bills_created_last30_days=None, bills_created_last12_months=None, license_features=None):
        super(LicenseResponse, self).__init__()
        self.validation_key = validation_key
        self.expiration_date = expiration_date
        self.licensed_meters = licensed_meters
        self.user_number = user_number
        self.version = version
        self.notes = notes
        self.meter_usage = meter_usage
        self.account_usage = account_usage
        self.bills_created_last30_days = bills_created_last30_days
        self.bills_created_last12_months = bills_created_last12_months
        self.license_features = license_features



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillUsage(Model):
    """BillUsage.

    :param manually_entered: Number of bills that are manually entered.
    :type manually_entered: int
    :param imported: Number of bills that are imported.
    :type imported: int
    :param chargeback: Number of bills that are chargeback.
    :type chargeback: int
    :param accrual: Number of bills that have accrued.
    :type accrual: int
    """

    _attribute_map = {
        'manually_entered': {'key': 'manuallyEntered', 'type': 'int'},
        'imported': {'key': 'imported', 'type': 'int'},
        'chargeback': {'key': 'chargeback', 'type': 'int'},
        'accrual': {'key': 'accrual', 'type': 'int'},
    }

    def __init__(self, manually_entered=None, imported=None, chargeback=None, accrual=None):
        super(BillUsage, self).__init__()
        self.manually_entered = manually_entered
        self.imported = imported
        self.chargeback = chargeback
        self.accrual = accrual



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RouteRequest(Model):
    """RouteRequest.

    :param route_info: The route info <span class='property-internal'>Must be
     between 0 and 32 characters</span> <span
     class='property-internal'>Required</span>
    :type route_info: str
    :param route_code: The route code
     This property has been deprecated. Route code will be generated from the
     value in route info <span class='property-internal'>Must be between 0 and
     16 characters</span>
    :type route_code: str
    :param meter_ids: The list of IDs for meters to be assigned to the route.
     The order in which the meter IDs appear will determine their order on the
     route.
     NOTE: if the same meter ID is passed in multiple times, the first
     occurrence of the meter ID will be used to determine the order on the
     route <span class='property-internal'>Required</span>
    :type meter_ids: list[int]
    """

    _validation = {
        'route_info': {'required': True, 'max_length': 32, 'min_length': 0},
        'route_code': {'max_length': 16, 'min_length': 0},
        'meter_ids': {'required': True},
    }

    _attribute_map = {
        'route_info': {'key': 'routeInfo', 'type': 'str'},
        'route_code': {'key': 'routeCode', 'type': 'str'},
        'meter_ids': {'key': 'meterIds', 'type': '[int]'},
    }

    def __init__(self, route_info, meter_ids, route_code=None):
        super(RouteRequest, self).__init__()
        self.route_info = route_info
        self.route_code = route_code
        self.meter_ids = meter_ids



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DestinationAccountMeterChild(Model):
    """DestinationAccountMeterChild.

    :param account_meter_id: The AccountMeter identifier <span
     class='property-internal'>Required (defined)</span>
    :type account_meter_id: int
    :param meter_id: The Meter identifier for this AccountMeter <span
     class='property-internal'>Required (defined)</span>
    :type meter_id: int
    :param meter_code: The code of the Meter for this AccountMeter <span
     class='property-internal'>Required (defined)</span>
    :type meter_code: str
    :param meter_info: The info of the Meter for this AccountMeter <span
     class='property-internal'>Required (defined)</span>
    :type meter_info: str
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    """

    _attribute_map = {
        'account_meter_id': {'key': 'accountMeterId', 'type': 'int'},
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
    }

    def __init__(self, account_meter_id=None, meter_id=None, meter_code=None, meter_info=None, commodity=None):
        super(DestinationAccountMeterChild, self).__init__()
        self.account_meter_id = account_meter_id
        self.meter_id = meter_id
        self.meter_code = meter_code
        self.meter_info = meter_info
        self.commodity = commodity



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RateResponse(Model):
    """RateResponse.

    :param rate_id:
    :type rate_id: int
    :param name:
    :type name: str
    :param note:
    :type note: str
    :param vendor:
    :type vendor: ~energycap.sdk.models.VendorChild
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param versions:
    :type versions: list[~energycap.sdk.models.VersionResponse]
    """

    _attribute_map = {
        'rate_id': {'key': 'rateId', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'note': {'key': 'note', 'type': 'str'},
        'vendor': {'key': 'vendor', 'type': 'VendorChild'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'versions': {'key': 'versions', 'type': '[VersionResponse]'},
    }

    def __init__(self, rate_id=None, name=None, note=None, vendor=None, commodity=None, versions=None):
        super(RateResponse, self).__init__()
        self.rate_id = rate_id
        self.name = name
        self.note = note
        self.vendor = vendor
        self.commodity = commodity
        self.versions = versions



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterDigestGHGYearlyResponseGHGScope(Model):
    """MeterDigestGHGYearlyResponseGHGScope.

    :param ghg_scope_id: GHG scope identifier
    :type ghg_scope_id: int
    :param ghg_scope_code: GHG scope code
    :type ghg_scope_code: str
    :param ghg_scope_info: GHG scope info
    :type ghg_scope_info: str
    :param ghg_scope_type_code: GHG scope type code
    :type ghg_scope_type_code: str
    :param ghg_scope_type_info: GHG scope type code
    :type ghg_scope_type_info: str
    """

    _attribute_map = {
        'ghg_scope_id': {'key': 'ghgScopeId', 'type': 'int'},
        'ghg_scope_code': {'key': 'ghgScopeCode', 'type': 'str'},
        'ghg_scope_info': {'key': 'ghgScopeInfo', 'type': 'str'},
        'ghg_scope_type_code': {'key': 'ghgScopeTypeCode', 'type': 'str'},
        'ghg_scope_type_info': {'key': 'ghgScopeTypeInfo', 'type': 'str'},
    }

    def __init__(self, ghg_scope_id=None, ghg_scope_code=None, ghg_scope_info=None, ghg_scope_type_code=None, ghg_scope_type_info=None):
        super(MeterDigestGHGYearlyResponseGHGScope, self).__init__()
        self.ghg_scope_id = ghg_scope_id
        self.ghg_scope_code = ghg_scope_code
        self.ghg_scope_info = ghg_scope_info
        self.ghg_scope_type_code = ghg_scope_type_code
        self.ghg_scope_type_info = ghg_scope_type_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountMeterRequest(Model):
    """AccountMeterRequest.

    :param account_id: The account identifier for this account meter <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Topmost (Account)</span>
    :type account_id: int
    :param meter_id: The meter identifier for this account meter <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Topmost (Meter)</span>
    :type meter_id: int
    :param begin_date: The beginning date and time for this account meter
     relationship
     Defaults to 1899-01-01
    :type begin_date: datetime
    :param end_date: The ending date and time for this account meter
     relationship
     Defaults to 3000-01-01
    :type end_date: datetime
    :param general_ledger_id: The identifier for the general ledger assigned
     to this account meter
    :type general_ledger_id: int
    :param vendor_type_id: The identifier for the vendor type. Vendors may
     assume different types on different account meters
    :type vendor_type_id: int
    :param deregulated: Indicates if the account meter is deregulated
    :type deregulated: bool
    :param template_id: The account meter template to be used for bill entry
     Optional.
     If passed in, the templateId will be used. If not passed
     If vendortypeid is 2 (supplier),
     --then a template on this meter's commodity with code that starts with
     S_meter's use unit code will be used
     --if not found we will try to use a template on this meter's commodity
     with code that starts with S_
     --If not found we will use a non-supplier template described below
     If vendortype is non- supplier
     -- the template will be defaulted using the meter's assigned use and
     demand units
     --First try and match template by commodityId, useUnitId, demandUnitId
     --If no match try commodityId, useUnitId
     --If no match select the first use only template that matches on commodity
     --If no match find the first template on this commodity
     --If none is found no template will be assigned
    :type template_id: int
    :param rate_id: Indicates if the account meter rate <span
     class='property-internal'>Required</span>
    :type rate_id: int
    """

    _validation = {
        'account_id': {'required': True},
        'meter_id': {'required': True},
        'rate_id': {'required': True},
    }

    _attribute_map = {
        'account_id': {'key': 'accountId', 'type': 'int'},
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'general_ledger_id': {'key': 'generalLedgerId', 'type': 'int'},
        'vendor_type_id': {'key': 'vendorTypeId', 'type': 'int'},
        'deregulated': {'key': 'deregulated', 'type': 'bool'},
        'template_id': {'key': 'templateId', 'type': 'int'},
        'rate_id': {'key': 'rateId', 'type': 'int'},
    }

    def __init__(self, account_id, meter_id, rate_id, begin_date=None, end_date=None, general_ledger_id=None, vendor_type_id=None, deregulated=None, template_id=None):
        super(AccountMeterRequest, self).__init__()
        self.account_id = account_id
        self.meter_id = meter_id
        self.begin_date = begin_date
        self.end_date = end_date
        self.general_ledger_id = general_ledger_id
        self.vendor_type_id = vendor_type_id
        self.deregulated = deregulated
        self.template_id = template_id
        self.rate_id = rate_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DashboardCreate(Model):
    """DashboardCreate.

    :param dashboard_info: The Dashboard Title <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type dashboard_info: str
    :param description: The dashboard description <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type description: str
    :param type: The dashboard type <span class='property-internal'>One of
     User, Map </span>
    :type type: str
    :param public: Flag to indicate if the dashboard is public
    :type public: bool
    """

    _validation = {
        'dashboard_info': {'required': True, 'max_length': 255, 'min_length': 0},
        'description': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'dashboard_info': {'key': 'dashboardInfo', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'public': {'key': 'public', 'type': 'bool'},
    }

    def __init__(self, dashboard_info, description=None, type=None, public=None):
        super(DashboardCreate, self).__init__()
        self.dashboard_info = dashboard_info
        self.description = description
        self.type = type
        self.public = public



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class LatestBenchmarkValue(Model):
    """LatestBenchmarkValue.

    :param benchmark_value:
    :type benchmark_value: ~energycap.sdk.models.BenchmarkValue
    :param benchmark_indicator: Indicator for which benchmark factor
    :type benchmark_indicator: int
    :param benchmark_info: benchmark info
    :type benchmark_info: str
    :param benchmark_category:
    :type benchmark_category: ~energycap.sdk.models.BenchmarkCategoryResponse
    """

    _attribute_map = {
        'benchmark_value': {'key': 'benchmarkValue', 'type': 'BenchmarkValue'},
        'benchmark_indicator': {'key': 'benchmarkIndicator', 'type': 'int'},
        'benchmark_info': {'key': 'benchmarkInfo', 'type': 'str'},
        'benchmark_category': {'key': 'benchmarkCategory', 'type': 'BenchmarkCategoryResponse'},
    }

    def __init__(self, benchmark_value=None, benchmark_indicator=None, benchmark_info=None, benchmark_category=None):
        super(LatestBenchmarkValue, self).__init__()
        self.benchmark_value = benchmark_value
        self.benchmark_indicator = benchmark_indicator
        self.benchmark_info = benchmark_info
        self.benchmark_category = benchmark_category



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListActionExportHold(Model):
    """ListActionExportHold.

    :param export_hold:  <span class='property-internal'>Required
     (defined)</span>
    :type export_hold: bool
    """

    _attribute_map = {
        'export_hold': {'key': 'exportHold', 'type': 'bool'},
    }

    def __init__(self, export_hold=None):
        super(ListActionExportHold, self).__init__()
        self.export_hold = export_hold



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RateVersionResponse(Model):
    """RateVersionResponse.

    :param version_id: ID of the rate schedule version
    :type version_id: int
    :param begin_date: Begin date for the version
    :type begin_date: datetime
    :param end_date: End date for the version
    :type end_date: datetime
    :param created_date: Created date
    :type created_date: datetime
    :param modified_date: Last modified date
    :type modified_date: datetime
    :param note: Note
    :type note: str
    :param created_by:
    :type created_by: ~energycap.sdk.models.UserChild
    :param modified_by:
    :type modified_by: ~energycap.sdk.models.UserChild
    :param use_unit_cost: Unit cost for the use
    :type use_unit_cost: float
    :param use_unit:
    :type use_unit: ~energycap.sdk.models.UnitChild
    :param demand_unit_cost: Unit cost for the demand
    :type demand_unit_cost: float
    :param demand_unit:
    :type demand_unit: ~energycap.sdk.models.UnitChild
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param account_line_items: Cost bodylines for the account
    :type account_line_items:
     list[~energycap.sdk.models.GenericBodylineResponse]
    :param meter_line_items: Cost bodylines for the meter
    :type meter_line_items:
     list[~energycap.sdk.models.GenericBodylineResponse]
    """

    _attribute_map = {
        'version_id': {'key': 'versionId', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'modified_date': {'key': 'modifiedDate', 'type': 'iso-8601'},
        'note': {'key': 'note', 'type': 'str'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'modified_by': {'key': 'modifiedBy', 'type': 'UserChild'},
        'use_unit_cost': {'key': 'useUnitCost', 'type': 'float'},
        'use_unit': {'key': 'useUnit', 'type': 'UnitChild'},
        'demand_unit_cost': {'key': 'demandUnitCost', 'type': 'float'},
        'demand_unit': {'key': 'demandUnit', 'type': 'UnitChild'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'account_line_items': {'key': 'accountLineItems', 'type': '[GenericBodylineResponse]'},
        'meter_line_items': {'key': 'meterLineItems', 'type': '[GenericBodylineResponse]'},
    }

    def __init__(self, version_id=None, begin_date=None, end_date=None, created_date=None, modified_date=None, note=None, created_by=None, modified_by=None, use_unit_cost=None, use_unit=None, demand_unit_cost=None, demand_unit=None, cost_unit=None, account_line_items=None, meter_line_items=None):
        super(RateVersionResponse, self).__init__()
        self.version_id = version_id
        self.begin_date = begin_date
        self.end_date = end_date
        self.created_date = created_date
        self.modified_date = modified_date
        self.note = note
        self.created_by = created_by
        self.modified_by = modified_by
        self.use_unit_cost = use_unit_cost
        self.use_unit = use_unit
        self.demand_unit_cost = demand_unit_cost
        self.demand_unit = demand_unit
        self.cost_unit = cost_unit
        self.account_line_items = account_line_items
        self.meter_line_items = meter_line_items



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RollupUnitUpdate(Model):
    """RollupUnitUpdate.

    :param common_rollups:  <span class='property-internal'>Required
     (defined)</span>
    :type common_rollups:
     list[~energycap.sdk.models.RollupUnitUpdateCommonUnit]
    :param global_rollup_unit_id:  <span class='property-internal'>Required
     (defined)</span>
    :type global_rollup_unit_id: int
    """

    _attribute_map = {
        'common_rollups': {'key': 'commonRollups', 'type': '[RollupUnitUpdateCommonUnit]'},
        'global_rollup_unit_id': {'key': 'globalRollupUnitId', 'type': 'int'},
    }

    def __init__(self, common_rollups=None, global_rollup_unit_id=None):
        super(RollupUnitUpdate, self).__init__()
        self.common_rollups = common_rollups
        self.global_rollup_unit_id = global_rollup_unit_id
